kegg_pull
=========
The ``kegg_pull`` package provides a number of useful CLI and API features for interacting with the KEGG REST API. This includes wrapper methods/commands for all the REST API operations, pulling lists of KEGG entry IDs, and pulling an unlimited number of KEGG entries, in a single call, that are automatically separated and saved in individual files. See `our documentation <https://moseleybioinformaticslab.github.io/kegg_pull/>`__ for more details.
